@@ -28,7 +28,7 @@ Breton_LO_Latest_main
    <fa>Breton Language Meta-Package for LibreOffice</fa>
    <fil_PH>Breton Language Meta-Package for LibreOffice</fil_PH>
    <fi>Bretonilainen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Breton Language Meta-Package for LibreOffice</fr_BE>
+   <fr_BE>Méta-Paquet de langue bretonne pour LibreOffice</fr_BE>
    <fr>Méta-Paquet de langue bretonne pour LibreOffice</fr>
    <gl_ES>Bretón Meta-paquete de Idioma para LibreOffice</gl_ES>
    <he_IL>Breton Language Meta-Package for LibreOffice</he_IL>
