@@ -28,7 +28,7 @@ Icelandic_Thunderbird
    <fa>Icelandic localisation of Thunderbird</fa>
    <fil_PH>Icelandic localisation of Thunderbird</fil_PH>
    <fi>Islantilainen Thunderbird-kotoistus</fi>
-   <fr_BE>Icelandic localisation of Thunderbird</fr_BE>
+   <fr_BE>Localisation islandaise pour Thunderbird</fr_BE>
    <fr>Localisation islandaise pour Thunderbird</fr>
    <gl_ES>Localización de Thunderbird ao islandés</gl_ES>
    <he_IL>תרגומי Thunderbird לאיסלנדית</he_IL>
