@@ -28,7 +28,7 @@ Russian_LO_Latest_full
    <fa>Russian localisation of LibreOffice</fa>
    <fil_PH>Russian localisation of LibreOffice</fil_PH>
    <fi>Venäläinen kotoistus LibreOffice:lle</fi>
-   <fr_BE>Russian localisation of LibreOffice</fr_BE>
+   <fr_BE>Localisation en russe pour LibreOffice</fr_BE>
    <fr>Localisation en russe pour LibreOffice</fr>
    <gl_ES>Localización do LibreOffice ao ruso</gl_ES>
    <he_IL>תרגומי LibreOffice לרוסית</he_IL>
