@@ -28,7 +28,7 @@ Slovenian_Firefox
    <fa>Slovenian localisation of Firefox</fa>
    <fil_PH>Slovenian localisation of Firefox</fil_PH>
    <fi>Slovenialainen Firefox-kotoistus</fi>
-   <fr_BE>Slovenian localisation of Firefox</fr_BE>
+   <fr_BE>Localisation en slovène pour Firefox</fr_BE>
    <fr>Localisation en slovène pour Firefox</fr>
    <gl_ES>Localización de Firefox ao esloveno</gl_ES>
    <he_IL>Slovenian localisation of Firefox</he_IL>
