@@ -28,7 +28,7 @@ Telugu_LO_Latest_main
    <fa>Telugu Language Meta-Package for LibreOffice</fa>
    <fil_PH>Telugu Language Meta-Package for LibreOffice</fil_PH>
    <fi>Telugunkielinen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Telugu Language Meta-Package for LibreOffice</fr_BE>
+   <fr_BE>Méta-Paquet de langue Telougou pour LibreOffice</fr_BE>
    <fr>Méta-Paquet de langue Telougou pour LibreOffice</fr>
    <gl_ES>Telego Meta-paquete de Idioma para LibreOffice</gl_ES>
    <he_IL>Telugu Language Meta-Package for LibreOffice</he_IL>
