@@ -28,7 +28,7 @@ Thai_LO_Latest_main
    <fa>Thai Language Meta-Package for LibreOffice</fa>
    <fil_PH>Thai Language Meta-Package for LibreOffice</fil_PH>
    <fi>Thainkielinen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Thai Language Meta-Package for LibreOffice</fr_BE>
+   <fr_BE>Méta-Paquet en langue thaïlandaise pour LibreOffice</fr_BE>
    <fr>Méta-Paquet en langue thaïlandaise pour LibreOffice</fr>
    <gl_ES>Tailandés Meta-paquete de Idioma para LibreOffice</gl_ES>
    <he_IL>Thai Language Meta-Package for LibreOffice</he_IL>
