@@ -28,7 +28,7 @@ Ukrainian_LO_full
    <fa>Ukrainian localisation of LibreOffice</fa>
    <fil_PH>Ukrainian localisation of LibreOffice</fil_PH>
    <fi>Ukrainalainen kotoistus LibreOffice:lle</fi>
-   <fr_BE>Ukrainian localisation of LibreOffice</fr_BE>
+   <fr_BE>Localisation en ukrainien pour LibreOffice</fr_BE>
    <fr>Localisation en ukrainien pour LibreOffice</fr>
    <gl_ES>Localización do LibreOffice ao ucraniano</gl_ES>
    <he_IL>תרגומי LibreOffice לאוקראינית</he_IL>
