@@ -28,7 +28,7 @@ adobe flash
    <fa>Official Adobe Flash, including plugins for chromium (pepperflash) and firefox</fa>
    <fil_PH>Official Adobe Flash, including plugins for chromium (pepperflash) and firefox</fil_PH>
    <fi>Virallinen Adobe Flash, sisältäen liitännäiset Chromium:ille (pepperflash) sekä Firefox:ille</fi>
-   <fr_BE>Official Adobe Flash, including plugins for chromium (pepperflash) and firefox</fr_BE>
+   <fr_BE>Adobe Flash officiel, incluant plugins pour Chromium (pepperflash) et Firefox</fr_BE>
    <fr>Adobe Flash officiel, incluant plugins pour Chromium (pepperflash) et Firefox</fr>
    <gl_ES>Flash oficial da Adobe que inclúe suplementos (plugins) para chromium (pepperflash) e firefox</gl_ES>
    <he_IL>Official Adobe Flash, including plugins for chromium (pepperflash) and firefox</he_IL>
