@@ -28,7 +28,7 @@ MPD Music Player Daemon
    <fa>a flexible, powerful, server-side application for playing music</fa>
    <fil_PH>a flexible, powerful, server-side application for playing music</fil_PH>
    <fi>joustava, tehokas, palvelinpuolen sovellus musiikinsoittamiseen</fi>
-   <fr_BE>a flexible, powerful, server-side application for playing music</fr_BE>
+   <fr_BE>Une application server-side souple et puissante pour lire de la musique</fr_BE>
    <fr>Une application server-side souple et puissante pour lire de la musique</fr>
    <gl_ES>Aplicativo de servidor, flexible e poderosa, para reprodución de música</gl_ES>
    <he_IL>a flexible, powerful, server-side application for playing music</he_IL>
